==> vacuum-1.1.0.tar.xz: vacuum-1.1.0/src/translations/ru/normalmessagehandler.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru" sourcelanguage="en">
<context>
    <name>NormalMessageHandler</name>
    <message>
        <source>Single Messages</source>
        <translation>Отдельные сообщения</translation>
    </message>
    <message>
        <source>Message from %1</source>
        <translation>Сообщение от %1</translation>
    </message>
    <message>
        <source>Message received</source>
        <translation>Получено сообщение</translation>
    </message>
    <message>
        <source>Composing message</source>
        <translation>Создание сообщения</translation>
    </message>
    <message>
        <source>%1 - Message</source>
        <translation>%1 - Сообщение</translation>
    </message>
    <message>
        <source>Re: %1</source>
        <translation>Re: %1</translation>
    </message>
    <message>
        <source>Fw: %1</source>
        <translation>Fw: %1</translation>
    </message>
    <message>
        <source>&lt;b&gt;The message with a error code %1 is received&lt;/b&gt;</source>
        <translation>&lt;b&gt; Получено сообщение с ошибкой № %1&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Subject: %1</source>
        <translation>Тема: %1</translation>
    </message>
    <message>
        <source>&lt;no subject&gt;</source>
        <translation>&lt;без темы&gt;</translation>
    </message>
    <message>
        <source>Normal Messages</source>
        <translation>Обычные сообщения</translation>
    </message>
    <message>
        <source>Allows to exchange normal messages</source>
        <translation>Позволяет обмениваться обычными сообщениями</translation>
    </message>
    <message>
        <source>Send message</source>
        <translation>Отправить сообщение</translation>
    </message>
    <message>
        <source>Ctrl+Return</source>
        <comment>Send message</comment>
        <translation>Ctrl+Return</translation>
    </message>
</context>
</TS>

==> vacuum-1.1.2_1798.tar.xz: vacuum-1.1.2_1798/src/translations/ru/normalmessagehandler.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru" sourcelanguage="en">
<context>
    <name>NormalMessageHandler</name>
    <message>
        <source>Message from %1</source>
        <translation>Сообщение от %1</translation>
    </message>
    <message>
        <source>Message received</source>
        <translation>Получено сообщение</translation>
    </message>
    <message>
        <source>Composing message</source>
        <translation>Создание сообщения</translation>
    </message>
    <message>
        <source>%1 - Message</source>
        <translation>%1 - Сообщение</translation>
    </message>
    <message>
        <source>Re: %1</source>
        <translation>Re: %1</translation>
    </message>
    <message>
        <source>Fw: %1</source>
        <translation>Fw: %1</translation>
    </message>
    <message>
        <source>&lt;b&gt;The message with a error code %1 is received&lt;/b&gt;</source>
        <translation>&lt;b&gt; Получено сообщение с ошибкой № %1&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Subject: %1</source>
        <translation>Тема: %1</translation>
    </message>
    <message>
        <source>&lt;no subject&gt;</source>
        <translation>&lt;без темы&gt;</translation>
    </message>
    <message>
        <source>Normal Messages</source>
        <translation>Обычные сообщения</translation>
    </message>
    <message>
        <source>Allows to exchange normal messages</source>
        <translation>Позволяет обмениваться обычными сообщениями</translation>
    </message>
    <message>
        <source>Send message</source>
        <translation>Отправить сообщение</translation>
    </message>
    <message>
        <source>Ctrl+Return</source>
        <comment>Send message</comment>
        <translation>Ctrl+Return</translation>
    </message>
    <message>
        <source>When receiving new single message</source>
        <translation>При получении нового отдельно сообщения</translation>
    </message>
</context>
</TS>
